package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.OmstruckOrderMapper;
import com.steerinfo.dil.mapper.OmstruckOrderMaterialMapper;
import com.steerinfo.dil.mapper.TmstruckTotalResultMapper;
import com.steerinfo.dil.model.OmstruckOrder;
import com.steerinfo.dil.model.OmstruckOrderMaterial;
import com.steerinfo.dil.model.TmstruckTotalResult;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.dil.model.AmstruckSporadicOrder;
import com.steerinfo.dil.mapper.AmstruckSporadicOrderMapper;
import com.steerinfo.dil.service.IAmstruckSporadicOrderService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * AmstruckSporadicOrder服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-12-16 02:49
 * 类描述
 * 修订历史：
 * 日期：2021-12-16
 * 作者：generator
 * 参考：
 * 描述：AmstruckSporadicOrder服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "amstruckSporadicOrderService")
public class AmstruckSporadicOrderServiceImpl implements IAmstruckSporadicOrderService {

    @Autowired
    private AmstruckSporadicOrderMapper amstruckSporadicOrderMapper;
    @Autowired
    OmstruckOrderMapper omstruckOrderMapper;
    @Autowired
    OmstruckOrderMaterialMapper omstruckOrderMaterialMapper;
    @Autowired
    TmstruckTotalResultMapper tmstruckTotalResultMapper;


    /**
     * 新增零星物资进出厂（以及销售钢材退货）
     * @param mapValue
     * @return
     */
    @Transactional
    @Override
    public int addSporadicOrders(Map<String, Object> mapValue) {
        int result = 0;
        // 新增零星订单表
        // 发货单位
        BigDecimal sendUnit = new BigDecimal((Integer) mapValue.get("supplierId"));
        // 收货单位
        BigDecimal receiveUnitId = new BigDecimal((Integer) mapValue.get("receiveId"));
        // 承运商
        BigDecimal carrierId = new BigDecimal((Integer) mapValue.get("carrierId"));
        // 得到订单类型
        BigDecimal orderType = new BigDecimal((Integer) mapValue.get("orderType"));
        // 得到运输路径
        BigDecimal lineId = new BigDecimal((Integer) mapValue.get("lineId"));
        BigDecimal sporadicOrderId = amstruckSporadicOrderMapper.selectSporadicOrderId();
        AmstruckSporadicOrder amstruckSporadicOrder = new AmstruckSporadicOrder();
        amstruckSporadicOrder.setSporadicOrderId(sporadicOrderId);
        amstruckSporadicOrder.setSporadicOrderNo(DataChange.generateEightDigitsNumber("WLXDD",sporadicOrderId.intValue()));
        amstruckSporadicOrder.setSendUnitId(sendUnit);
        amstruckSporadicOrder.setReceiveUnitId(receiveUnitId);
        amstruckSporadicOrder.setCarrierId(carrierId);
        amstruckSporadicOrder.setIssueStatus(new BigDecimal(0));
        amstruckSporadicOrder.setInsertTime(new Date());
        amstruckSporadicOrder.setInsertUsername("admin");
        amstruckSporadicOrder.setDeleted(new BigDecimal(0));
        amstruckSporadicOrder.setInsertUpdateRemark("无");
        List<Map<String,Object>> mapList = (List<Map<String, Object>>) mapValue.get("mapList");
        // 新增运输订单表
        OmstruckOrder omstruckOrder = new OmstruckOrder();
        BigDecimal orderId = omstruckOrderMapper.selectMaxId();
        omstruckOrder.setOrderId(orderId);
        omstruckOrder.setOrderPlanId(sporadicOrderId);
        omstruckOrder.setOrderNumber(DataChange.generateEightDigitsNumber("WYSDD",orderId.intValue()));
        omstruckOrder.setOrderType(orderType);
        omstruckOrder.setInsertTime(new Date());
        omstruckOrder.setInsertUsername("admin");
        omstruckOrder.setInsertUpdateRemark("无");
        omstruckOrder.setLineId(lineId);
        //新增总实绩id
        TmstruckTotalResult tmstruckTotalResult=new TmstruckTotalResult();
        tmstruckTotalResult.setResultTotalId(tmstruckTotalResultMapper.selectTmstruckTotalResultId());
        tmstruckTotalResult.setOrderId(omstruckOrder.getOrderId());
        //新增总实绩
        result += tmstruckTotalResultMapper.insertSelective(tmstruckTotalResult);
        result += amstruckSporadicOrderMapper.insertSelective(amstruckSporadicOrder);
        result += omstruckOrderMapper.insertSelective(omstruckOrder);
        for (Map<String, Object> map : mapList) {
            BigDecimal materialId = new BigDecimal((Integer) map.get("materialId"));
            BigDecimal materialWeight = DataChange.dataToBigDecimal(map.get("orderMaterialWeight"));
            BigDecimal materialNumber =DataChange.dataToBigDecimal(map.get("orderMaterialNumber"));
            OmstruckOrderMaterial omstruckOrderMaterial = new OmstruckOrderMaterial();
            BigDecimal orderMaterialId = omstruckOrderMaterialMapper.selectMaxId();
            omstruckOrderMaterial.setOrderMaterialId(orderMaterialId);
            omstruckOrderMaterial.setOrderId(orderId);
            omstruckOrderMaterial.setMaterialId(materialId);
            //设置物资装货优先级
            omstruckOrderMaterial.setMaterialPriority(DataChange.dataToBigDecimal(map.get("materialPriority")));
            omstruckOrderMaterial.setInsertUsername("admin");
            omstruckOrderMaterial.setInsertTime(new Date());
            if (materialWeight != null) {
                omstruckOrderMaterial.setOrderMaterialWeight(materialWeight);
            }
            if (materialNumber != null) {
                omstruckOrderMaterial.setOrderMaterialNumber(materialNumber);
            }
            result += omstruckOrderMaterialMapper.insertSelective(omstruckOrderMaterial);
        }
        return result;
    }

    /**
     * 下发零星物资订单
     * @param mapList
     * @return
     */
    @Override
    public int issueSporadicOrders(List<Map<String, Object>> mapList) {
        int result = 0;
        // 遍历
        for (Map<String, Object> map : mapList) {
            OmstruckOrder omstruckOrder=new OmstruckOrder();
            omstruckOrder.setOrderId(DataChange.dataToBigDecimal(map.get("orderId")));
            omstruckOrder.setOrderStatus(new BigDecimal(3));
            //修改零星物资订单状态
            AmstruckSporadicOrder amstruckSporadicOrder=new AmstruckSporadicOrder();
            amstruckSporadicOrder.setSporadicOrderId(DataChange.dataToBigDecimal(map.get("sporadicOrderId")));
            amstruckSporadicOrder.setIssueStatus(new BigDecimal(1));
            result +=amstruckSporadicOrderMapper.updateByPrimaryKeySelective(amstruckSporadicOrder);
            result += omstruckOrderMapper.updateByPrimaryKeySelective(omstruckOrder);
        }
        return result;
    }

    /**
     * 逻辑删除零星物资订单
     * @param sporadicOrderId
     * @return
     */
    @Override
    public int deleteSporadicOrders(Integer sporadicOrderId) {
        int result = 0;
        AmstruckSporadicOrder amstruckSporadicOrder = amstruckSporadicOrderMapper.selectByPrimaryKey(new BigDecimal(sporadicOrderId));
        amstruckSporadicOrder.setDeleted(new BigDecimal(1));
        result += amstruckSporadicOrderMapper.updateByPrimaryKeySelective(amstruckSporadicOrder);
        return result;
    }

    /**
     * 查询零星物资订单列表
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> getSporadicOrdersList(Map<String, Object> mapValue) {
        List<Map<String,Object>> mapList = amstruckSporadicOrderMapper.getSporadicOrdersList(mapValue);
        for (Map<String, Object> map : mapList) {
            BigDecimal type = (BigDecimal) map.get("type");
            String orderType = "";
            if (type.intValue() == 12) {
                orderType += "零星物资进厂";
            }
            if (type.intValue() == 13) {
                orderType += "零星物资出厂";
            }
            map.put("orderType",orderType);
        }
        return mapList;
    }

    /**
     * 查询物资详情
     * @param mapValue
     * @return
     */
    @Override
    public List<Map<String, Object>> seeAllMaterials(Map<String,Object> mapValue) {
        List<Map<String,Object>> mapList = amstruckSporadicOrderMapper.seeAllMaterials(mapValue);
        return mapList;
    }

    /**
     * 修改零星物资订单
     * @param mapValue
     * @return
     */
    @Override
    public int updateSporadicOrder(Map<String, Object> mapValue) {
        BigDecimal sporadicOrderId = new BigDecimal((Integer) mapValue.get("sporadicOrderId"));
        BigDecimal sendUnitId = new BigDecimal((Integer) mapValue.get("sendUnitId"));
        BigDecimal receiveUnitId = new BigDecimal((Integer) mapValue.get("receiveUnitId"));
        BigDecimal carrierId = new BigDecimal((Integer) mapValue.get("carrierId"));
        AmstruckSporadicOrder amstruckSporadicOrder = amstruckSporadicOrderMapper.selectByPrimaryKey(sporadicOrderId);
        amstruckSporadicOrder.setSendUnitId(sendUnitId);
        amstruckSporadicOrder.setReceiveUnitId(receiveUnitId);
        amstruckSporadicOrder.setCarrierId(carrierId);
        amstruckSporadicOrder.setUpdateTime(new Date());
        amstruckSporadicOrder.setUpdateUsername("admin");
        int result = amstruckSporadicOrderMapper.updateByPrimaryKeySelective(amstruckSporadicOrder);
        return result;
    }

    /**
     * 查询修改渲染
     * @param sporadicOrderId
     * @return
     */
    @Override
    public List<Map<String, Object>> selectSporadicOrder(Integer sporadicOrderId) {
        List<Map<String, Object>> mapList = amstruckSporadicOrderMapper.selectSporadicOrder(new BigDecimal(sporadicOrderId));
        return mapList;
    }
}
